ScaleResult class

Constructors

ScaleResult({required double scale, required double adaptedDpr, required AdaptStrategy strategy, required Size designSize, required Size logicalSize})
const

Properties

adaptedDpr double
final
designSize Size
final
hashCode int
The hash code for this object.
no setteroverride
logicalSize Size
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
final
strategy AdaptStrategy
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override