StatusBarConfig class

Constructors

StatusBarConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentPlatformThreshold double
no setter

Static Methods

forPlatform(TargetPlatform platform) double

Constants

android → const double
defaultThreshold → const double
harmonyOS → const double
iOS → const double