SystemInfo class

Constructors

SystemInfo({Size physicalSize = Size.zero, double dpr = 1.0, Size logicalSize = Size.zero, EdgeInsets viewPadding = EdgeInsets.zero, EdgeInsets padding = EdgeInsets.zero, EdgeInsets viewInsets = EdgeInsets.zero, double systemTextScale = 1.0, List<DisplayFeature> displayFeatures = const []})
const
SystemInfo.fromFlutterView(FlutterView view)
factory
SystemInfo.fromMediaQuery(MediaQueryData data)
factory

Properties

displayFeatures List<DisplayFeature>
final
dpr double
final
hashCode int
The hash code for this object.
no setteroverride
hingeBounds Rect?
no setter
isFlat bool
no setter
isFolded bool
no setter
logicalSize Size
final
orientation Orientation
no setter
padding EdgeInsets
final
physicalSize Size
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemTextScale double
final
viewInsets EdgeInsets
final
viewPadding EdgeInsets
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override