AdaptContext extension

on

Properties

adaptFoldState FoldState?

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptHingeBounds Rect?

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptNotchInfo NotchInfo?

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptOrientation Orientation

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSafeBottom double

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSafeLeft double

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSafeRight double

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSafeTop double

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptScale double

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptScaleResult ScaleResult?

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSupportSystemTextScale bool

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptSystemInfo SystemInfo?

Available on BuildContext, provided by the AdaptContext extension

no setter
adaptTextBehavior TextBehavior

Available on BuildContext, provided by the AdaptContext extension

no setter
isFlat bool

Available on BuildContext, provided by the AdaptContext extension

no setter
isFolded bool

Available on BuildContext, provided by the AdaptContext extension

no setter
notchHeight double

Available on BuildContext, provided by the AdaptContext extension

Height of the notch (刘海) area specifically. Returns (topInset - statusBarThreshold) when topInset exceeds the threshold, otherwise returns 0. Use this when you need to know how much the notch extends beyond the status bar.
no setter
statusBarHeight double

Available on BuildContext, provided by the AdaptContext extension

Height of the status bar area. Returns the platform-specific threshold (e.g., 24pt on iOS, 25pt on Android) if the top inset exceeds it, otherwise returns the raw top inset value. Use this when you need the actual status bar height for layout calculations.
no setter