NotchOverride class
Represents the physical posture of a foldable device.
flat: Device is fully open/unfoldedhalfOpened: Device is partially folded (e.g., laptop mode)unknown: Unable to determine (either not a foldable device, or posture could not be detected)
Constructors
Properties
- bottomInset → double
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- leftInset → double
-
final
- rightInset → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topInset → double
-
final
- type → NotchType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override