TextScaleDecider class

Constructors

TextScaleDecider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compute({required double uiScale, double systemTextScale = 1.0, TextBehavior behavior = TextBehavior.scale, bool supportSystemTextScale = true}) double