FoldableClassifier class
- Inheritance
-
- Object
- NotchClassifier
- FoldableClassifier
Constructors
- FoldableClassifier({NotchClassifier baseClassifier = const IOSNotchClassifier()})
-
const
Properties
- baseClassifier → NotchClassifier
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
classify(
SystemInfo info, {Orientation? orientation}) → NotchInfo -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getFoldPosture(
SystemInfo info) → FoldState? -
isFoldableDevice(
SystemInfo info) → bool