NotchInfo class
Constructors
-
NotchInfo({required NotchType type, double topInset = 0, double bottomInset = 0, double leftInset = 0, double rightInset = 0, List<
Rect> cutoutRects = const [], FoldState? foldState, Rect? hingeBounds, Orientation? orientation}) -
const
- NotchInfo.fromFoldable({required SystemInfo info, required NotchType type, double topInset = 0, double bottomInset = 0, double leftInset = 0, double rightInset = 0})
-
factory
Properties
- bottomInset → double
-
final
-
cutoutRects
→ List<
Rect> -
final
- foldState → FoldState?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hingeBounds → Rect?
-
final
- insets → EdgeInsets
-
no setter
- leftInset → double
-
final
- orientation → Orientation?
-
final
- rightInset → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topInset → double
-
final
- type → NotchType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override